Saying class

Constructors

Saying({required String content, required SayingType type, String? author, Language language = Language.zh, int? weekday})
const
Saying.fromJson(Map<String, dynamic> json, Language language)
factory

Properties

author String?
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
language Language
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SayingType
final
weekday int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited